<?php

/**
 * @file
 * Contains a ParserInterface
 *
 * @license GPL v2 http://www.fsf.org/licensing/licenses/gpl.html
 * @author Chris Skene chris at previousnext dot com dot au
 * @copyright Copyright(c) 2014 Christopher Skene and PreviousNext
 */

namespace Drupal\fabricator\Parser;

use Drupal\fabricator\Component\Component;
use Drupal\fabricator\Exception\FabricatorException;

/**
 * Interface ParserInterface
 * @package Drupal\fabricator\Parser
 */
interface ParserInterface {

  /**
   * Parse a Source (either a blueprint or component).
   *
   * This should set the blueprint property on the Component with the
   * exported item.
   *
   * @param Component $component
   *   The component to parse a source for.
   *
   * @return mixed
   *   The source.
   *
   * @throws FabricatorException
   */
  public function parseSource(Component $component);

  /**
   * Get the content.
   *
   * @param Component $component
   *   The component to parse a source for.
   *
   * @return array
   *   An array of defined vars
   */
  public function getContent(Component $component);
}
