<?php

/**
 * @file
 * Contains a ParserManager
 *
 * @license GPL v2 http://www.fsf.org/licensing/licenses/gpl.html
 * @author Chris Skene chris at previousnext dot com dot au
 * @copyright Copyright(c) 2014 Christopher Skene and PreviousNext
 */

namespace Drupal\fabricator\Parser;

use Drupal\fabricator\Exception\FabricatorException;

/**
 * Class ParserManager
 * @package Drupal\fabricator\Parser
 */
class ParserManager {

  /**
   * Constructor.
   */
  public function __construct() {

  }

  /**
   * Lazy constructor.
   *
   * @return ParserManager
   *   This object.
   */
  static public function init() {
    return new static();
  }

  /**
   * Get Parser information.
   *
   * @return array
   *   An array of parsers.
   */
  public function getParsers() {

    $implementers = module_implements('fabricator_parsers');
    if (empty($implementers)) {
      return array();
    }

    $factories = array();
    foreach ($implementers as $module_name) {

      $module_factories = module_invoke($module_name, 'fabricator_parsers');
      if (empty($module_factories)) {
        continue;
      }

      foreach ($module_factories as $key => $module_factory) {
        $defaults = array(
          'name' => '',
          'class' => NULL,
          'provider' => $module_name,
          'machine_name' => $key,
        );

        $factories[$key] = array_merge($defaults, $module_factory);
      }
    }

    return $factories;
  }

  /**
   * Get an individual parser.
   *
   * @param string $name
   *   Name of the parser.
   *
   * @return ParserInterface
   *   A Parser.
   *
   * @throws FabricatorException
   */
  public function getParser($name) {

    $parsers = $this->getParsers();

    if (array_key_exists($name, $parsers)) {
      if (class_exists($parsers[$name]['class'])) {
        $parser = new $parsers[$name]['class']();

        if ($parser instanceof ParserInterface) {
          return $parser;
        }
      }
    }

    throw new FabricatorException('Invalid Parser');
  }
}
